aboutsummaryrefslogtreecommitdiffstats
path: root/lib/compiler/src/beam_ssa_type.erl
diff options
context:
space:
mode:
authorJohn Högberg <[email protected]>2019-06-28 09:14:43 +0200
committerJohn Högberg <[email protected]>2019-07-05 11:33:38 +0200
commita10fb1edf471602be01bd5b4c1f019cc5534b9f5 (patch)
tree588664b6b7019227a04494b88037be732238f918 /lib/compiler/src/beam_ssa_type.erl
parentec35aa92f49dedf4b25a78c6b8d56d629db6642d (diff)
downloadotp-a10fb1edf471602be01bd5b4c1f019cc5534b9f5.tar.gz
otp-a10fb1edf471602be01bd5b4c1f019cc5534b9f5.tar.bz2
otp-a10fb1edf471602be01bd5b4c1f019cc5534b9f5.zip
compiler: Explain and rename ?BADARG_BLOCK
Diffstat (limited to 'lib/compiler/src/beam_ssa_type.erl')
-rw-r--r--lib/compiler/src/beam_ssa_type.erl6
1 files changed, 3 insertions, 3 deletions
diff --git a/lib/compiler/src/beam_ssa_type.erl b/lib/compiler/src/beam_ssa_type.erl
index f87acdb500..5e7b54a064 100644
--- a/lib/compiler/src/beam_ssa_type.erl
+++ b/lib/compiler/src/beam_ssa_type.erl
@@ -108,7 +108,7 @@ opt_continue_1(Linear0, Args, Id, Ts, FuncDb0) ->
D = #d{ func_db=FuncDb0,
func_id=Id,
ds=Defs,
- ls=#{0=>Ts,?BADARG_BLOCK=>#{}},
+ ls=#{0=>Ts,?EXCEPTION_BLOCK=>#{}},
once=UsedOnce },
{Linear, FuncDb, NewRet} = opt(Linear0, D, []),
@@ -892,8 +892,8 @@ sub_sw_list_1(Type, [{Val,_}|T], Ts) ->
sub_sw_list_1(Type, [], _Ts) ->
Type.
-update_successor(?BADARG_BLOCK, _Ts, #d{}=D) ->
- %% We KNOW that no variables are used in the ?BADARG_BLOCK,
+update_successor(?EXCEPTION_BLOCK, _Ts, #d{}=D) ->
+ %% We KNOW that no variables are used in the ?EXCEPTION_BLOCK,
%% so there is no need to update the type information. That
%% can be a huge timesaver for huge functions.
D;